from outetts.version.v1.interface import InterfaceGGUF
from transformers import PreTrainedModel

from document_to_podcast.inference.text_to_speech import text_to_speech


def test_text_to_speech_oute(mocker):
    model = mocker.MagicMock(spec_set=InterfaceGGUF)
    text_to_speech(
        "Hello?",
        model=model,
        voice_profile="female_1",
    )
    model.load_default_speaker.assert_called_with(name=mocker.ANY)
    model.generate.assert_called_with(
        text=mocker.ANY,
        temperature=mocker.ANY,
        repetition_penalty=mocker.ANY,
        max_length=mocker.ANY,
        speaker=mocker.ANY,
    )


def test_text_to_speech_parler(mocker):
    model = mocker.MagicMock(spec_set=PreTrainedModel)
    tokenizer = mocker.MagicMock()
    text_to_speech(
        "Hello?",
        model=model,
        tokenizer=tokenizer,
        voice_profile="default",
    )
    tokenizer.assert_has_calls(
        [
            mocker.call("default", return_tensors="pt"),
            mocker.call("Hello?", return_tensors="pt"),
        ]
    )
    model.generate.assert_called_with(input_ids=mocker.ANY, prompt_input_ids=mocker.ANY)



from llama_cpp import Llama

from document_to_podcast.inference.model_loaders import (
    load_llama_cpp_model,
    load_outetts_model,
)
from transformers import PreTrainedModel, PreTrainedTokenizerBase
from outetts.version.v1.interface import InterfaceGGUF

from document_to_podcast.inference.model_loaders import (
    load_parler_tts_model_and_tokenizer,
)


def test_load_llama_cpp_model():
    model = load_llama_cpp_model(
        "HuggingFaceTB/smollm-135M-instruct-v0.2-Q8_0-GGUF/smollm-135m-instruct-add-basics-q8_0.gguf"
    )
    assert isinstance(model, Llama)
    # we set n_ctx=0 to indicate that we want to use the model's default context
    assert model.n_ctx() == 2048


def test_load_outetts_model():
    model = load_outetts_model(
        "OuteAI/OuteTTS-0.1-350M-GGUF/OuteTTS-0.1-350M-Q2_K.gguf"
    )
    assert isinstance(model, InterfaceGGUF)


def test_load_parler_tts_model_and_tokenizer():
    model, tokenizer = load_parler_tts_model_and_tokenizer(
        "parler-tts/parler-tts-mini-v1"
    )
    assert isinstance(model, PreTrainedModel)
    assert isinstance(tokenizer, PreTrainedTokenizerBase)
